"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.access.access_pb2
import yandex.cloud.operation.operation_pb2
import yandex.cloud.serverless.containers.v1.container_pb2
import yandex.cloud.serverless.containers.v1.container_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class ContainerServiceStub:
    """A set of methods for managing serverless containers."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.containers.v1.container_service_pb2.GetContainerRequest,
        yandex.cloud.serverless.containers.v1.container_pb2.Container,
    ]
    """Returns the specified container.

    To get the list of all available containers, make a [List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.containers.v1.container_service_pb2.ListContainersRequest,
        yandex.cloud.serverless.containers.v1.container_service_pb2.ListContainersResponse,
    ]
    """Retrieves the list of containers in the specified folder."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.containers.v1.container_service_pb2.CreateContainerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a container in the specified folder."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.containers.v1.container_service_pb2.UpdateContainerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified container."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.containers.v1.container_service_pb2.DeleteContainerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified container."""

    DeployRevision: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.containers.v1.container_service_pb2.DeployContainerRevisionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deploys a revision for the specified container."""

    Rollback: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.containers.v1.container_service_pb2.RollbackContainerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Rollback the specified container to an old revision."""

    GetRevision: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.containers.v1.container_service_pb2.GetContainerRevisionRequest,
        yandex.cloud.serverless.containers.v1.container_pb2.Revision,
    ]
    """Returns the specified revision of a container.

    To get the list of available revision, make a [ListRevisions] request.
    """

    ListRevisions: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.containers.v1.container_service_pb2.ListContainersRevisionsRequest,
        yandex.cloud.serverless.containers.v1.container_service_pb2.ListContainersRevisionsResponse,
    ]
    """Retrieves the list of revisions for the specified container, or of all container revisions
    in the specified folder.
    """

    ListOperations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.containers.v1.container_service_pb2.ListContainerOperationsRequest,
        yandex.cloud.serverless.containers.v1.container_service_pb2.ListContainerOperationsResponse,
    ]
    """Lists operations for the specified container."""

    ListAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """Lists existing access bindings for the specified container."""

    SetAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the container."""

    UpdateAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the specified container."""

class ContainerServiceAsyncStub:
    """A set of methods for managing serverless containers."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.containers.v1.container_service_pb2.GetContainerRequest,
        yandex.cloud.serverless.containers.v1.container_pb2.Container,
    ]
    """Returns the specified container.

    To get the list of all available containers, make a [List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.containers.v1.container_service_pb2.ListContainersRequest,
        yandex.cloud.serverless.containers.v1.container_service_pb2.ListContainersResponse,
    ]
    """Retrieves the list of containers in the specified folder."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.containers.v1.container_service_pb2.CreateContainerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a container in the specified folder."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.containers.v1.container_service_pb2.UpdateContainerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified container."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.containers.v1.container_service_pb2.DeleteContainerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified container."""

    DeployRevision: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.containers.v1.container_service_pb2.DeployContainerRevisionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deploys a revision for the specified container."""

    Rollback: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.containers.v1.container_service_pb2.RollbackContainerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Rollback the specified container to an old revision."""

    GetRevision: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.containers.v1.container_service_pb2.GetContainerRevisionRequest,
        yandex.cloud.serverless.containers.v1.container_pb2.Revision,
    ]
    """Returns the specified revision of a container.

    To get the list of available revision, make a [ListRevisions] request.
    """

    ListRevisions: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.containers.v1.container_service_pb2.ListContainersRevisionsRequest,
        yandex.cloud.serverless.containers.v1.container_service_pb2.ListContainersRevisionsResponse,
    ]
    """Retrieves the list of revisions for the specified container, or of all container revisions
    in the specified folder.
    """

    ListOperations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.containers.v1.container_service_pb2.ListContainerOperationsRequest,
        yandex.cloud.serverless.containers.v1.container_service_pb2.ListContainerOperationsResponse,
    ]
    """Lists operations for the specified container."""

    ListAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """Lists existing access bindings for the specified container."""

    SetAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the container."""

    UpdateAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the specified container."""

class ContainerServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing serverless containers."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.serverless.containers.v1.container_service_pb2.GetContainerRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.serverless.containers.v1.container_pb2.Container, collections.abc.Awaitable[yandex.cloud.serverless.containers.v1.container_pb2.Container]]:
        """Returns the specified container.

        To get the list of all available containers, make a [List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.serverless.containers.v1.container_service_pb2.ListContainersRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.serverless.containers.v1.container_service_pb2.ListContainersResponse, collections.abc.Awaitable[yandex.cloud.serverless.containers.v1.container_service_pb2.ListContainersResponse]]:
        """Retrieves the list of containers in the specified folder."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.serverless.containers.v1.container_service_pb2.CreateContainerRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a container in the specified folder."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.serverless.containers.v1.container_service_pb2.UpdateContainerRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified container."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.serverless.containers.v1.container_service_pb2.DeleteContainerRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified container."""

    @abc.abstractmethod
    def DeployRevision(
        self,
        request: yandex.cloud.serverless.containers.v1.container_service_pb2.DeployContainerRevisionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deploys a revision for the specified container."""

    @abc.abstractmethod
    def Rollback(
        self,
        request: yandex.cloud.serverless.containers.v1.container_service_pb2.RollbackContainerRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Rollback the specified container to an old revision."""

    @abc.abstractmethod
    def GetRevision(
        self,
        request: yandex.cloud.serverless.containers.v1.container_service_pb2.GetContainerRevisionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.serverless.containers.v1.container_pb2.Revision, collections.abc.Awaitable[yandex.cloud.serverless.containers.v1.container_pb2.Revision]]:
        """Returns the specified revision of a container.

        To get the list of available revision, make a [ListRevisions] request.
        """

    @abc.abstractmethod
    def ListRevisions(
        self,
        request: yandex.cloud.serverless.containers.v1.container_service_pb2.ListContainersRevisionsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.serverless.containers.v1.container_service_pb2.ListContainersRevisionsResponse, collections.abc.Awaitable[yandex.cloud.serverless.containers.v1.container_service_pb2.ListContainersRevisionsResponse]]:
        """Retrieves the list of revisions for the specified container, or of all container revisions
        in the specified folder.
        """

    @abc.abstractmethod
    def ListOperations(
        self,
        request: yandex.cloud.serverless.containers.v1.container_service_pb2.ListContainerOperationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.serverless.containers.v1.container_service_pb2.ListContainerOperationsResponse, collections.abc.Awaitable[yandex.cloud.serverless.containers.v1.container_service_pb2.ListContainerOperationsResponse]]:
        """Lists operations for the specified container."""

    @abc.abstractmethod
    def ListAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.access.access_pb2.ListAccessBindingsResponse, collections.abc.Awaitable[yandex.cloud.access.access_pb2.ListAccessBindingsResponse]]:
        """Lists existing access bindings for the specified container."""

    @abc.abstractmethod
    def SetAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Sets access bindings for the container."""

    @abc.abstractmethod
    def UpdateAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates access bindings for the specified container."""

def add_ContainerServiceServicer_to_server(servicer: ContainerServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.monitoring.v3.dashboard_pb2
import yandex.cloud.monitoring.v3.parametrization_pb2
import yandex.cloud.monitoring.v3.widget_pb2
import yandex.cloud.operation.operation_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetDashboardRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DASHBOARD_ID_FIELD_NUMBER: builtins.int
    dashboard_id: builtins.str
    """Required. Dashboard ID."""
    def __init__(
        self,
        *,
        dashboard_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dashboard_id", b"dashboard_id"]) -> None: ...

global___GetDashboardRequest = GetDashboardRequest

@typing.final
class ListDashboardsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """Required. Folder ID."""
    page_size: builtins.int
    """The maximum number of dashboards to return.
    If unspecified, at most 100 dashboards will be returned.
    The maximum value is 1000; values above 1000 will be coerced to 1000.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListDashboardResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    The expression must specify:
    1. The field name. Currently you can use filtering only on the [Dashboard.name] field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    Example: name="abc"
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["container", b"container", "folder_id", b"folder_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["container", b"container", "filter", b"filter", "folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["container", b"container"]) -> typing.Literal["folder_id"] | None: ...

global___ListDashboardsRequest = ListDashboardsRequest

@typing.final
class ListDashboardsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DASHBOARDS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token to retrieve the next page of results, or empty if there are no more results in the list."""
    @property
    def dashboards(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.monitoring.v3.dashboard_pb2.Dashboard]:
        """List of dashboards."""

    def __init__(
        self,
        *,
        dashboards: collections.abc.Iterable[yandex.cloud.monitoring.v3.dashboard_pb2.Dashboard] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dashboards", b"dashboards", "next_page_token", b"next_page_token"]) -> None: ...

global___ListDashboardsResponse = ListDashboardsResponse

@typing.final
class CreateDashboardRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    WIDGETS_FIELD_NUMBER: builtins.int
    PARAMETRIZATION_FIELD_NUMBER: builtins.int
    MANAGED_BY_FIELD_NUMBER: builtins.int
    MANAGED_LINK_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """Required. Folder ID."""
    name: builtins.str
    """Required. Dashboard name."""
    description: builtins.str
    """Dashboard description."""
    title: builtins.str
    """Dashboard title."""
    managed_by: builtins.str
    """Entity that controls dashboard
    Must match the regular expression "[\\w \\-]{1,100}"
    """
    managed_link: builtins.str
    """Information about entity that controls dashboard
    Must be valid URI
    """
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs."""

    @property
    def widgets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.monitoring.v3.widget_pb2.Widget]:
        """List of dashboard widgets."""

    @property
    def parametrization(self) -> yandex.cloud.monitoring.v3.parametrization_pb2.Parametrization:
        """Dashboard parametrization."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        title: builtins.str = ...,
        widgets: collections.abc.Iterable[yandex.cloud.monitoring.v3.widget_pb2.Widget] | None = ...,
        parametrization: yandex.cloud.monitoring.v3.parametrization_pb2.Parametrization | None = ...,
        managed_by: builtins.str = ...,
        managed_link: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["container", b"container", "folder_id", b"folder_id", "parametrization", b"parametrization"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["container", b"container", "description", b"description", "folder_id", b"folder_id", "labels", b"labels", "managed_by", b"managed_by", "managed_link", b"managed_link", "name", b"name", "parametrization", b"parametrization", "title", b"title", "widgets", b"widgets"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["container", b"container"]) -> typing.Literal["folder_id"] | None: ...

global___CreateDashboardRequest = CreateDashboardRequest

@typing.final
class CreateDashboardMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DASHBOARD_ID_FIELD_NUMBER: builtins.int
    dashboard_id: builtins.str
    """Dashboard ID."""
    def __init__(
        self,
        *,
        dashboard_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dashboard_id", b"dashboard_id"]) -> None: ...

global___CreateDashboardMetadata = CreateDashboardMetadata

@typing.final
class UpdateDashboardRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    DASHBOARD_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    WIDGETS_FIELD_NUMBER: builtins.int
    PARAMETRIZATION_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    MANAGED_BY_FIELD_NUMBER: builtins.int
    MANAGED_LINK_FIELD_NUMBER: builtins.int
    dashboard_id: builtins.str
    """Required. Dashboard ID."""
    name: builtins.str
    """Required. Dashboard name."""
    description: builtins.str
    """Dashboard description."""
    title: builtins.str
    """Dashboard title."""
    etag: builtins.str
    """The current etag of the dashboard."""
    managed_by: builtins.str
    """Entity that controls dashboard
    Must match the regular expression "[\\w \\-]{1,100}"
    """
    managed_link: builtins.str
    """Information about entity that controls dashboard
    Must be valid URI
    """
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs.

        Existing set of `labels` is completely replaced by the provided set.
        """

    @property
    def widgets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.monitoring.v3.widget_pb2.Widget]:
        """List of dashboard widgets."""

    @property
    def parametrization(self) -> yandex.cloud.monitoring.v3.parametrization_pb2.Parametrization:
        """Dashboard parametrization."""

    def __init__(
        self,
        *,
        dashboard_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        title: builtins.str = ...,
        widgets: collections.abc.Iterable[yandex.cloud.monitoring.v3.widget_pb2.Widget] | None = ...,
        parametrization: yandex.cloud.monitoring.v3.parametrization_pb2.Parametrization | None = ...,
        etag: builtins.str = ...,
        managed_by: builtins.str = ...,
        managed_link: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["parametrization", b"parametrization"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["dashboard_id", b"dashboard_id", "description", b"description", "etag", b"etag", "labels", b"labels", "managed_by", b"managed_by", "managed_link", b"managed_link", "name", b"name", "parametrization", b"parametrization", "title", b"title", "widgets", b"widgets"]) -> None: ...

global___UpdateDashboardRequest = UpdateDashboardRequest

@typing.final
class UpdateDashboardMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DASHBOARD_ID_FIELD_NUMBER: builtins.int
    dashboard_id: builtins.str
    """Dashboard ID."""
    def __init__(
        self,
        *,
        dashboard_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dashboard_id", b"dashboard_id"]) -> None: ...

global___UpdateDashboardMetadata = UpdateDashboardMetadata

@typing.final
class DeleteDashboardRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DASHBOARD_ID_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    dashboard_id: builtins.str
    """Required. Dashboard ID."""
    etag: builtins.str
    """The current etag of the dashboard."""
    def __init__(
        self,
        *,
        dashboard_id: builtins.str = ...,
        etag: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dashboard_id", b"dashboard_id", "etag", b"etag"]) -> None: ...

global___DeleteDashboardRequest = DeleteDashboardRequest

@typing.final
class DeleteDashboardMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DASHBOARD_ID_FIELD_NUMBER: builtins.int
    dashboard_id: builtins.str
    """Dashboard ID."""
    def __init__(
        self,
        *,
        dashboard_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dashboard_id", b"dashboard_id"]) -> None: ...

global___DeleteDashboardMetadata = DeleteDashboardMetadata

@typing.final
class ListDashboardOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DASHBOARD_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    dashboard_id: builtins.str
    """ID of the dashboard to list operations for."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size], the service returns a [ListDashboardOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListDashboardOperationsResponse.next_page_token] returned by a previous list request.
    """
    def __init__(
        self,
        *,
        dashboard_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dashboard_id", b"dashboard_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListDashboardOperationsRequest = ListDashboardOperationsRequest

@typing.final
class ListDashboardOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListDashboardOperationsRequest.page_size], use the [next_page_token] as the value
    for the [ListDashboardOperationsRequest.page_token] query parameter in the next list request.
    Each subsequent list request will have its own [next_page_token] to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified dashboard."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListDashboardOperationsResponse = ListDashboardOperationsResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/serverless/workflows/v1/history_entry.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8yandex/cloud/serverless/workflows/v1/history_entry.proto\x12$yandex.cloud.serverless.workflows.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\xcc\x04\n\x0cHistoryEntry\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12.\n\nstarted_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x08\x64uration\x18\x05 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x46\n\x05input\x18\x06 \x01(\x0b\x32\x37.yandex.cloud.serverless.workflows.v1.HistoryEntryInput\x12H\n\x06output\x18\x07 \x01(\x0b\x32\x38.yandex.cloud.serverless.workflows.v1.HistoryEntryOutput\x12\x46\n\x05\x65rror\x18\x08 \x01(\x0b\x32\x37.yandex.cloud.serverless.workflows.v1.HistoryEntryError\x12I\n\x06status\x18\t \x01(\x0e\x32\x39.yandex.cloud.serverless.workflows.v1.HistoryEntry.Status\x12\x0c\n\x04type\x18\n \x01(\t\"|\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\r\n\tSCHEDULED\x10\x01\x12\x0b\n\x07STARTED\x10\x02\x12\r\n\tCOMPLETED\x10\x03\x12\n\n\x06\x46\x41ILED\x10\x04\x12\x14\n\x10\x43\x41NCEL_REQUESTED\x10\x05\x12\r\n\tCANCELLED\x10\x06\"8\n\x11HistoryEntryInput\x12\x14\n\ninput_json\x18\x01 \x01(\tH\x00\x42\r\n\x05input\x12\x04\xc0\xc1\x31\x01\";\n\x12HistoryEntryOutput\x12\x15\n\x0boutput_json\x18\x01 \x01(\tH\x00\x42\x0e\n\x06output\x12\x04\xc0\xc1\x31\x01\"8\n\x11HistoryEntryError\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x12\n\nerror_code\x18\x02 \x01(\tB~\n(yandex.cloud.api.serverless.workflows.v1ZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/workflows/v1;workflowsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.serverless.workflows.v1.history_entry_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(yandex.cloud.api.serverless.workflows.v1ZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/workflows/v1;workflows'
  _HISTORYENTRYINPUT.oneofs_by_name['input']._options = None
  _HISTORYENTRYINPUT.oneofs_by_name['input']._serialized_options = b'\300\3011\001'
  _HISTORYENTRYOUTPUT.oneofs_by_name['output']._options = None
  _HISTORYENTRYOUTPUT.oneofs_by_name['output']._serialized_options = b'\300\3011\001'
  _globals['_HISTORYENTRY']._serialized_start=195
  _globals['_HISTORYENTRY']._serialized_end=783
  _globals['_HISTORYENTRY_STATUS']._serialized_start=659
  _globals['_HISTORYENTRY_STATUS']._serialized_end=783
  _globals['_HISTORYENTRYINPUT']._serialized_start=785
  _globals['_HISTORYENTRYINPUT']._serialized_end=841
  _globals['_HISTORYENTRYOUTPUT']._serialized_start=843
  _globals['_HISTORYENTRYOUTPUT']._serialized_end=902
  _globals['_HISTORYENTRYERROR']._serialized_start=904
  _globals['_HISTORYENTRYERROR']._serialized_end=960
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _QuantileType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _QuantileTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_QuantileType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    QUANTILE_TYPE_UNSPECIFIED: _QuantileType.ValueType  # 0
    """Unspecified percentile."""
    QUANTILE_TYPE_50: _QuantileType.ValueType  # 1
    """50 percentile (median)."""
    QUANTILE_TYPE_75: _QuantileType.ValueType  # 2
    """75 percentile."""
    QUANTILE_TYPE_80: _QuantileType.ValueType  # 3
    """80 percentile."""
    QUANTILE_TYPE_85: _QuantileType.ValueType  # 4
    """85 percentile."""
    QUANTILE_TYPE_90: _QuantileType.ValueType  # 5
    """90 percentile."""
    QUANTILE_TYPE_95: _QuantileType.ValueType  # 6
    """95 percentile."""
    QUANTILE_TYPE_98: _QuantileType.ValueType  # 7
    """98 percentile."""
    QUANTILE_TYPE_99: _QuantileType.ValueType  # 8
    """99 percentile."""
    QUANTILE_TYPE_100: _QuantileType.ValueType  # 9
    """100 percentile (maximum or minimum)."""

class QuantileType(_QuantileType, metaclass=_QuantileTypeEnumTypeWrapper):
    """Quantiles (percentiles)."""

QUANTILE_TYPE_UNSPECIFIED: QuantileType.ValueType  # 0
"""Unspecified percentile."""
QUANTILE_TYPE_50: QuantileType.ValueType  # 1
"""50 percentile (median)."""
QUANTILE_TYPE_75: QuantileType.ValueType  # 2
"""75 percentile."""
QUANTILE_TYPE_80: QuantileType.ValueType  # 3
"""80 percentile."""
QUANTILE_TYPE_85: QuantileType.ValueType  # 4
"""85 percentile."""
QUANTILE_TYPE_90: QuantileType.ValueType  # 5
"""90 percentile."""
QUANTILE_TYPE_95: QuantileType.ValueType  # 6
"""95 percentile."""
QUANTILE_TYPE_98: QuantileType.ValueType  # 7
"""98 percentile."""
QUANTILE_TYPE_99: QuantileType.ValueType  # 8
"""99 percentile."""
QUANTILE_TYPE_100: QuantileType.ValueType  # 9
"""100 percentile (maximum or minimum)."""
global___QuantileType = QuantileType

@typing.final
class Quantiles(google.protobuf.message.Message):
    """Statistical data aggregated by predefined set of quantiles."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    Q50_FIELD_NUMBER: builtins.int
    Q75_FIELD_NUMBER: builtins.int
    Q80_FIELD_NUMBER: builtins.int
    Q85_FIELD_NUMBER: builtins.int
    Q90_FIELD_NUMBER: builtins.int
    Q95_FIELD_NUMBER: builtins.int
    Q98_FIELD_NUMBER: builtins.int
    Q99_FIELD_NUMBER: builtins.int
    Q100_FIELD_NUMBER: builtins.int
    q50: builtins.float
    """50 percentile (median)."""
    q75: builtins.float
    """75 percentile."""
    q80: builtins.float
    """80 percentile."""
    q85: builtins.float
    """85 percentile."""
    q90: builtins.float
    """90 percentile."""
    q95: builtins.float
    """95 percentile."""
    q98: builtins.float
    """98 percentile."""
    q99: builtins.float
    """99 percentile."""
    q100: builtins.float
    """100 percentile (maximum or minimum)."""
    def __init__(
        self,
        *,
        q50: builtins.float = ...,
        q75: builtins.float = ...,
        q80: builtins.float = ...,
        q85: builtins.float = ...,
        q90: builtins.float = ...,
        q95: builtins.float = ...,
        q98: builtins.float = ...,
        q99: builtins.float = ...,
        q100: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["q100", b"q100", "q50", b"q50", "q75", b"q75", "q80", b"q80", "q85", b"q85", "q90", b"q90", "q95", b"q95", "q98", b"q98", "q99", b"q99"]) -> None: ...

global___Quantiles = Quantiles



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _AsymmetricSignatureAlgorithm:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _AsymmetricSignatureAlgorithmEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_AsymmetricSignatureAlgorithm.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ASYMMETRIC_SIGNATURE_ALGORITHM_UNSPECIFIED: _AsymmetricSignatureAlgorithm.ValueType  # 0
    RSA_2048_SIGN_PSS_SHA_256: _AsymmetricSignatureAlgorithm.ValueType  # 1
    """RSA-2048 signature with PSS padding and SHA-256"""
    RSA_2048_SIGN_PSS_SHA_384: _AsymmetricSignatureAlgorithm.ValueType  # 2
    """RSA-2048 signature with PSS padding and SHA-384"""
    RSA_2048_SIGN_PSS_SHA_512: _AsymmetricSignatureAlgorithm.ValueType  # 3
    """RSA-2048 signature with PSS padding and SHA-512"""
    RSA_3072_SIGN_PSS_SHA_256: _AsymmetricSignatureAlgorithm.ValueType  # 4
    """RSA-3072 signature with PSS padding and SHA-256"""
    RSA_3072_SIGN_PSS_SHA_384: _AsymmetricSignatureAlgorithm.ValueType  # 5
    """RSA-3072 signature with PSS padding and SHA-384"""
    RSA_3072_SIGN_PSS_SHA_512: _AsymmetricSignatureAlgorithm.ValueType  # 6
    """RSA-3072 signature with PSS padding and SHA-512"""
    RSA_4096_SIGN_PSS_SHA_256: _AsymmetricSignatureAlgorithm.ValueType  # 7
    """RSA-4096 signature with PSS padding and SHA-256"""
    RSA_4096_SIGN_PSS_SHA_384: _AsymmetricSignatureAlgorithm.ValueType  # 8
    """RSA-4096 signature with PSS padding and SHA-384"""
    RSA_4096_SIGN_PSS_SHA_512: _AsymmetricSignatureAlgorithm.ValueType  # 9
    """RSA-4096 signature with PSS padding and SHA-512"""
    ECDSA_NIST_P256_SHA_256: _AsymmetricSignatureAlgorithm.ValueType  # 10
    """ECDSA signature with NIST P-256 curve and SHA-256"""
    ECDSA_NIST_P384_SHA_384: _AsymmetricSignatureAlgorithm.ValueType  # 11
    """ECDSA signature with NIST P-384 curve and SHA-384"""
    ECDSA_NIST_P521_SHA_512: _AsymmetricSignatureAlgorithm.ValueType  # 12
    """ECDSA signature with NIST P-521 curve and SHA-512"""
    ECDSA_SECP256_K1_SHA_256: _AsymmetricSignatureAlgorithm.ValueType  # 13
    """ECDSA signature with SECP256_K1 curve and SHA-256"""

class AsymmetricSignatureAlgorithm(_AsymmetricSignatureAlgorithm, metaclass=_AsymmetricSignatureAlgorithmEnumTypeWrapper):
    """Supported asymmetric signature algorithms."""

ASYMMETRIC_SIGNATURE_ALGORITHM_UNSPECIFIED: AsymmetricSignatureAlgorithm.ValueType  # 0
RSA_2048_SIGN_PSS_SHA_256: AsymmetricSignatureAlgorithm.ValueType  # 1
"""RSA-2048 signature with PSS padding and SHA-256"""
RSA_2048_SIGN_PSS_SHA_384: AsymmetricSignatureAlgorithm.ValueType  # 2
"""RSA-2048 signature with PSS padding and SHA-384"""
RSA_2048_SIGN_PSS_SHA_512: AsymmetricSignatureAlgorithm.ValueType  # 3
"""RSA-2048 signature with PSS padding and SHA-512"""
RSA_3072_SIGN_PSS_SHA_256: AsymmetricSignatureAlgorithm.ValueType  # 4
"""RSA-3072 signature with PSS padding and SHA-256"""
RSA_3072_SIGN_PSS_SHA_384: AsymmetricSignatureAlgorithm.ValueType  # 5
"""RSA-3072 signature with PSS padding and SHA-384"""
RSA_3072_SIGN_PSS_SHA_512: AsymmetricSignatureAlgorithm.ValueType  # 6
"""RSA-3072 signature with PSS padding and SHA-512"""
RSA_4096_SIGN_PSS_SHA_256: AsymmetricSignatureAlgorithm.ValueType  # 7
"""RSA-4096 signature with PSS padding and SHA-256"""
RSA_4096_SIGN_PSS_SHA_384: AsymmetricSignatureAlgorithm.ValueType  # 8
"""RSA-4096 signature with PSS padding and SHA-384"""
RSA_4096_SIGN_PSS_SHA_512: AsymmetricSignatureAlgorithm.ValueType  # 9
"""RSA-4096 signature with PSS padding and SHA-512"""
ECDSA_NIST_P256_SHA_256: AsymmetricSignatureAlgorithm.ValueType  # 10
"""ECDSA signature with NIST P-256 curve and SHA-256"""
ECDSA_NIST_P384_SHA_384: AsymmetricSignatureAlgorithm.ValueType  # 11
"""ECDSA signature with NIST P-384 curve and SHA-384"""
ECDSA_NIST_P521_SHA_512: AsymmetricSignatureAlgorithm.ValueType  # 12
"""ECDSA signature with NIST P-521 curve and SHA-512"""
ECDSA_SECP256_K1_SHA_256: AsymmetricSignatureAlgorithm.ValueType  # 13
"""ECDSA signature with SECP256_K1 curve and SHA-256"""
global___AsymmetricSignatureAlgorithm = AsymmetricSignatureAlgorithm

@typing.final
class AsymmetricSignatureKey(google.protobuf.message.Message):
    """An asymmetric KMS key that may contain several versions of the cryptographic material."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[AsymmetricSignatureKey._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: AsymmetricSignatureKey._Status.ValueType  # 0
        CREATING: AsymmetricSignatureKey._Status.ValueType  # 1
        """The key is being created."""
        ACTIVE: AsymmetricSignatureKey._Status.ValueType  # 2
        """The key is active and can be used for encryption and decryption or signature and verification.
        Can be set to INACTIVE using the [AsymmetricKeyService.Update] method.
        """
        INACTIVE: AsymmetricSignatureKey._Status.ValueType  # 3
        """The key is inactive and unusable.
        Can be set to ACTIVE using the [AsymmetricKeyService.Update] method.
        """

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: AsymmetricSignatureKey.Status.ValueType  # 0
    CREATING: AsymmetricSignatureKey.Status.ValueType  # 1
    """The key is being created."""
    ACTIVE: AsymmetricSignatureKey.Status.ValueType  # 2
    """The key is active and can be used for encryption and decryption or signature and verification.
    Can be set to INACTIVE using the [AsymmetricKeyService.Update] method.
    """
    INACTIVE: AsymmetricSignatureKey.Status.ValueType  # 3
    """The key is inactive and unusable.
    Can be set to ACTIVE using the [AsymmetricKeyService.Update] method.
    """

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    SIGNATURE_ALGORITHM_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the key."""
    folder_id: builtins.str
    """ID of the folder that the key belongs to."""
    name: builtins.str
    """Name of the key."""
    description: builtins.str
    """Description of the key."""
    status: global___AsymmetricSignatureKey.Status.ValueType
    """Current status of the key."""
    signature_algorithm: global___AsymmetricSignatureAlgorithm.ValueType
    """Signature Algorithm ID."""
    deletion_protection: builtins.bool
    """Flag that inhibits deletion of the key"""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time when the key was created."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Custom labels for the key as `key:value` pairs. Maximum 64 per key."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        status: global___AsymmetricSignatureKey.Status.ValueType = ...,
        signature_algorithm: global___AsymmetricSignatureAlgorithm.ValueType = ...,
        deletion_protection: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "deletion_protection", b"deletion_protection", "description", b"description", "folder_id", b"folder_id", "id", b"id", "labels", b"labels", "name", b"name", "signature_algorithm", b"signature_algorithm", "status", b"status"]) -> None: ...

global___AsymmetricSignatureKey = AsymmetricSignatureKey



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.datasphere.v2.community_pb2
import yandex.cloud.datasphere.v2.resource_types_pb2
import yandex.cloud.datasphere.v2.restrictions_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class CreateCommunityRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    BILLING_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    ZONE_ID_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the community."""
    description: builtins.str
    """Description of the community."""
    organization_id: builtins.str
    """ID of the organization where community should be created."""
    billing_account_id: builtins.str
    """ID of the billing account for the created community. Optional, billing account could be bound to community later."""
    zone_id: builtins.str
    """ID of the zone where community will be created (all projects and other resources will be in this zone)"""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Labels of the community."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        description: builtins.str = ...,
        organization_id: builtins.str = ...,
        billing_account_id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        zone_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["billing_account_id", b"billing_account_id", "description", b"description", "labels", b"labels", "name", b"name", "organization_id", b"organization_id", "zone_id", b"zone_id"]) -> None: ...

global___CreateCommunityRequest = CreateCommunityRequest

@typing.final
class CreateCommunityMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMUNITY_ID_FIELD_NUMBER: builtins.int
    community_id: builtins.str
    """ID of the community that is being created."""
    def __init__(
        self,
        *,
        community_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["community_id", b"community_id"]) -> None: ...

global___CreateCommunityMetadata = CreateCommunityMetadata

@typing.final
class GetCommunityRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMUNITY_ID_FIELD_NUMBER: builtins.int
    community_id: builtins.str
    """ID of the community."""
    def __init__(
        self,
        *,
        community_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["community_id", b"community_id"]) -> None: ...

global___GetCommunityRequest = GetCommunityRequest

@typing.final
class UpdateCommunityRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    COMMUNITY_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    community_id: builtins.str
    """ID of the community."""
    name: builtins.str
    """Name of the community."""
    description: builtins.str
    """Description of the community."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the Community resource are going to be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Labels of the community."""

    def __init__(
        self,
        *,
        community_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["community_id", b"community_id", "description", b"description", "labels", b"labels", "name", b"name", "update_mask", b"update_mask"]) -> None: ...

global___UpdateCommunityRequest = UpdateCommunityRequest

@typing.final
class UpdateCommunityMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMUNITY_ID_FIELD_NUMBER: builtins.int
    community_id: builtins.str
    """ID of the community that is being updated."""
    def __init__(
        self,
        *,
        community_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["community_id", b"community_id"]) -> None: ...

global___UpdateCommunityMetadata = UpdateCommunityMetadata

@typing.final
class DeleteCommunityRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMUNITY_ID_FIELD_NUMBER: builtins.int
    community_id: builtins.str
    """ID of the community."""
    def __init__(
        self,
        *,
        community_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["community_id", b"community_id"]) -> None: ...

global___DeleteCommunityRequest = DeleteCommunityRequest

@typing.final
class DeleteCommunityMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMUNITY_ID_FIELD_NUMBER: builtins.int
    community_id: builtins.str
    """ID of the community that is being deleted."""
    def __init__(
        self,
        *,
        community_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["community_id", b"community_id"]) -> None: ...

global___DeleteCommunityMetadata = DeleteCommunityMetadata

@typing.final
class ListCommunitiesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    NAME_OR_DESCRIPTION_PATTERN_FIELD_NUMBER: builtins.int
    OWNED_BY_ID_FIELD_NUMBER: builtins.int
    LIST_PUBLIC_FIELD_NUMBER: builtins.int
    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListCommunitiesResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListCommunitiesResponse.next_page_token] returned by a previous list request.
    """
    name_or_description_pattern: builtins.str
    """Community name or description pattern.
    Only communities with names or descriptions matching specified pattern will be returned.
    """
    owned_by_id: builtins.str
    """ID of the user. Only communities owned by specified user will be returned."""
    list_public: builtins.bool
    """If set to true, only public communities will be returned."""
    organization_id: builtins.str
    """ID of the organization to list communities in."""
    def __init__(
        self,
        *,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        name_or_description_pattern: builtins.str = ...,
        owned_by_id: builtins.str = ...,
        list_public: builtins.bool = ...,
        organization_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["list_public", b"list_public", "name_or_description_pattern", b"name_or_description_pattern", "organization_id", b"organization_id", "owned_by_id", b"owned_by_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListCommunitiesRequest = ListCommunitiesRequest

@typing.final
class ListCommunitiesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMUNITIES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListCommunitiesRequest.page_size], use
    the [next_page_token] as the value
    for the [ListCommunitiesRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def communities(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.datasphere.v2.community_pb2.Community]:
        """List of communities matching filters in list communities request."""

    def __init__(
        self,
        *,
        communities: collections.abc.Iterable[yandex.cloud.datasphere.v2.community_pb2.Community] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["communities", b"communities", "next_page_token", b"next_page_token"]) -> None: ...

global___ListCommunitiesResponse = ListCommunitiesResponse

@typing.final
class SetCommunityAccessBindingsMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMUNITY_ID_FIELD_NUMBER: builtins.int
    community_id: builtins.str
    """ID of the community which access bindings are set."""
    def __init__(
        self,
        *,
        community_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["community_id", b"community_id"]) -> None: ...

global___SetCommunityAccessBindingsMetadata = SetCommunityAccessBindingsMetadata

@typing.final
class UpdateCommunityAccessBindingsMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMUNITY_ID_FIELD_NUMBER: builtins.int
    community_id: builtins.str
    """ID of the community which access bindings are updated."""
    def __init__(
        self,
        *,
        community_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["community_id", b"community_id"]) -> None: ...

global___UpdateCommunityAccessBindingsMetadata = UpdateCommunityAccessBindingsMetadata

@typing.final
class AddCommunityResourceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMUNITY_ID_FIELD_NUMBER: builtins.int
    RESOURCE_TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_ID_FIELD_NUMBER: builtins.int
    community_id: builtins.str
    resource_type: yandex.cloud.datasphere.v2.resource_types_pb2.ResourceType.ValueType
    resource_id: builtins.str
    def __init__(
        self,
        *,
        community_id: builtins.str = ...,
        resource_type: yandex.cloud.datasphere.v2.resource_types_pb2.ResourceType.ValueType = ...,
        resource_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["community_id", b"community_id", "resource_id", b"resource_id", "resource_type", b"resource_type"]) -> None: ...

global___AddCommunityResourceRequest = AddCommunityResourceRequest

@typing.final
class RemoveCommunityResourceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMUNITY_ID_FIELD_NUMBER: builtins.int
    RESOURCE_TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_ID_FIELD_NUMBER: builtins.int
    community_id: builtins.str
    resource_type: yandex.cloud.datasphere.v2.resource_types_pb2.ResourceType.ValueType
    resource_id: builtins.str
    def __init__(
        self,
        *,
        community_id: builtins.str = ...,
        resource_type: yandex.cloud.datasphere.v2.resource_types_pb2.ResourceType.ValueType = ...,
        resource_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["community_id", b"community_id", "resource_id", b"resource_id", "resource_type", b"resource_type"]) -> None: ...

global___RemoveCommunityResourceRequest = RemoveCommunityResourceRequest

@typing.final
class GetCommunityRestrictionsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMUNITY_ID_FIELD_NUMBER: builtins.int
    community_id: builtins.str
    """ID of the community."""
    def __init__(
        self,
        *,
        community_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["community_id", b"community_id"]) -> None: ...

global___GetCommunityRestrictionsRequest = GetCommunityRestrictionsRequest

@typing.final
class SetCommunityRestrictionsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMUNITY_ID_FIELD_NUMBER: builtins.int
    RESTRICTIONS_FIELD_NUMBER: builtins.int
    community_id: builtins.str
    """ID of the community."""
    @property
    def restrictions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.datasphere.v2.restrictions_pb2.Restriction]:
        """List of restrictions to set."""

    def __init__(
        self,
        *,
        community_id: builtins.str = ...,
        restrictions: collections.abc.Iterable[yandex.cloud.datasphere.v2.restrictions_pb2.Restriction] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["community_id", b"community_id", "restrictions", b"restrictions"]) -> None: ...

global___SetCommunityRestrictionsRequest = SetCommunityRestrictionsRequest



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.serverless.triggers.v1.trigger_pb2
import yandex.cloud.serverless.triggers.v1.trigger_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class TriggerServiceStub:
    """A set of methods for managing triggers for serverless functions."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.triggers.v1.trigger_service_pb2.GetTriggerRequest,
        yandex.cloud.serverless.triggers.v1.trigger_pb2.Trigger,
    ]
    """Returns the specified trigger.

    To get the list of all available triggers, make a [List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.triggers.v1.trigger_service_pb2.ListTriggersRequest,
        yandex.cloud.serverless.triggers.v1.trigger_service_pb2.ListTriggersResponse,
    ]
    """Retrieves the list of triggers in the specified folder."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.triggers.v1.trigger_service_pb2.CreateTriggerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a trigger in the specified folder."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.triggers.v1.trigger_service_pb2.UpdateTriggerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified trigger."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.triggers.v1.trigger_service_pb2.DeleteTriggerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified trigger."""

    Pause: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.triggers.v1.trigger_service_pb2.PauseTriggerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Pauses the specified trigger."""

    Resume: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.triggers.v1.trigger_service_pb2.ResumeTriggerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Restarts the specified trigger."""

    ListOperations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.triggers.v1.trigger_service_pb2.ListTriggerOperationsRequest,
        yandex.cloud.serverless.triggers.v1.trigger_service_pb2.ListTriggerOperationsResponse,
    ]
    """Lists operations for the specified trigger."""

class TriggerServiceAsyncStub:
    """A set of methods for managing triggers for serverless functions."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.triggers.v1.trigger_service_pb2.GetTriggerRequest,
        yandex.cloud.serverless.triggers.v1.trigger_pb2.Trigger,
    ]
    """Returns the specified trigger.

    To get the list of all available triggers, make a [List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.triggers.v1.trigger_service_pb2.ListTriggersRequest,
        yandex.cloud.serverless.triggers.v1.trigger_service_pb2.ListTriggersResponse,
    ]
    """Retrieves the list of triggers in the specified folder."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.triggers.v1.trigger_service_pb2.CreateTriggerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a trigger in the specified folder."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.triggers.v1.trigger_service_pb2.UpdateTriggerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified trigger."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.triggers.v1.trigger_service_pb2.DeleteTriggerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified trigger."""

    Pause: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.triggers.v1.trigger_service_pb2.PauseTriggerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Pauses the specified trigger."""

    Resume: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.triggers.v1.trigger_service_pb2.ResumeTriggerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Restarts the specified trigger."""

    ListOperations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.triggers.v1.trigger_service_pb2.ListTriggerOperationsRequest,
        yandex.cloud.serverless.triggers.v1.trigger_service_pb2.ListTriggerOperationsResponse,
    ]
    """Lists operations for the specified trigger."""

class TriggerServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing triggers for serverless functions."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.serverless.triggers.v1.trigger_service_pb2.GetTriggerRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.serverless.triggers.v1.trigger_pb2.Trigger, collections.abc.Awaitable[yandex.cloud.serverless.triggers.v1.trigger_pb2.Trigger]]:
        """Returns the specified trigger.

        To get the list of all available triggers, make a [List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.serverless.triggers.v1.trigger_service_pb2.ListTriggersRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.serverless.triggers.v1.trigger_service_pb2.ListTriggersResponse, collections.abc.Awaitable[yandex.cloud.serverless.triggers.v1.trigger_service_pb2.ListTriggersResponse]]:
        """Retrieves the list of triggers in the specified folder."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.serverless.triggers.v1.trigger_service_pb2.CreateTriggerRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a trigger in the specified folder."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.serverless.triggers.v1.trigger_service_pb2.UpdateTriggerRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified trigger."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.serverless.triggers.v1.trigger_service_pb2.DeleteTriggerRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified trigger."""

    @abc.abstractmethod
    def Pause(
        self,
        request: yandex.cloud.serverless.triggers.v1.trigger_service_pb2.PauseTriggerRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Pauses the specified trigger."""

    @abc.abstractmethod
    def Resume(
        self,
        request: yandex.cloud.serverless.triggers.v1.trigger_service_pb2.ResumeTriggerRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Restarts the specified trigger."""

    @abc.abstractmethod
    def ListOperations(
        self,
        request: yandex.cloud.serverless.triggers.v1.trigger_service_pb2.ListTriggerOperationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.serverless.triggers.v1.trigger_service_pb2.ListTriggerOperationsResponse, collections.abc.Awaitable[yandex.cloud.serverless.triggers.v1.trigger_service_pb2.ListTriggerOperationsResponse]]:
        """Lists operations for the specified trigger."""

def add_TriggerServiceServicer_to_server(servicer: TriggerServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.ai.common.common_pb2
import yandex.cloud.ai.files.v1.file_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class CreateFileRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    MIME_TYPE_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    EXPIRATION_CONFIG_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    name: builtins.str
    description: builtins.str
    mime_type: builtins.str
    content: builtins.bytes
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def expiration_config(self) -> yandex.cloud.ai.common.common_pb2.ExpirationConfig: ...
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        mime_type: builtins.str = ...,
        content: builtins.bytes = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        expiration_config: yandex.cloud.ai.common.common_pb2.ExpirationConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["expiration_config", b"expiration_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["content", b"content", "description", b"description", "expiration_config", b"expiration_config", "folder_id", b"folder_id", "labels", b"labels", "mime_type", b"mime_type", "name", b"name"]) -> None: ...

global___CreateFileRequest = CreateFileRequest

@typing.final
class GetFileRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILE_ID_FIELD_NUMBER: builtins.int
    file_id: builtins.str
    def __init__(
        self,
        *,
        file_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["file_id", b"file_id"]) -> None: ...

global___GetFileRequest = GetFileRequest

@typing.final
class GetFileUrlRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILE_ID_FIELD_NUMBER: builtins.int
    file_id: builtins.str
    def __init__(
        self,
        *,
        file_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["file_id", b"file_id"]) -> None: ...

global___GetFileUrlRequest = GetFileUrlRequest

@typing.final
class GetFileUrlResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    url: builtins.str
    def __init__(
        self,
        *,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["url", b"url"]) -> None: ...

global___GetFileUrlResponse = GetFileUrlResponse

@typing.final
class UpdateFileRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FILE_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPIRATION_CONFIG_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    file_id: builtins.str
    name: builtins.str
    description: builtins.str
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask: ...
    @property
    def expiration_config(self) -> yandex.cloud.ai.common.common_pb2.ExpirationConfig: ...
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        file_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        expiration_config: yandex.cloud.ai.common.common_pb2.ExpirationConfig | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["expiration_config", b"expiration_config", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "expiration_config", b"expiration_config", "file_id", b"file_id", "labels", b"labels", "name", b"name", "update_mask", b"update_mask"]) -> None: ...

global___UpdateFileRequest = UpdateFileRequest

@typing.final
class DeleteFileRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILE_ID_FIELD_NUMBER: builtins.int
    file_id: builtins.str
    def __init__(
        self,
        *,
        file_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["file_id", b"file_id"]) -> None: ...

global___DeleteFileRequest = DeleteFileRequest

@typing.final
class DeleteFileResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteFileResponse = DeleteFileResponse

@typing.final
class ListFilesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    page_size: builtins.int
    page_token: builtins.str
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListFilesRequest = ListFilesRequest

@typing.final
class ListFilesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    @property
    def files(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.ai.files.v1.file_pb2.File]: ...
    def __init__(
        self,
        *,
        files: collections.abc.Iterable[yandex.cloud.ai.files.v1.file_pb2.File] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["files", b"files", "next_page_token", b"next_page_token"]) -> None: ...

global___ListFilesResponse = ListFilesResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/compute/v1/disk_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.compute.v1 import disk_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_disk__pb2
from yandex.cloud.compute.v1 import hardware_generation_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_hardware__generation__pb2
from yandex.cloud.compute.v1 import snapshot_schedule_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*yandex/cloud/compute/v1/disk_service.proto\x12\x17yandex.cloud.compute.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/access/access.proto\x1a yandex/cloud/api/operation.proto\x1a\"yandex/cloud/compute/v1/disk.proto\x1a\x31yandex/cloud/compute/v1/hardware_generation.proto\x1a/yandex/cloud/compute/v1/snapshot_schedule.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"/\n\x0eGetDiskRequest\x12\x1d\n\x07\x64isk_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\xaa\x01\n\x10ListDisksRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x1b\n\x08order_by\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05<=100\"Z\n\x11ListDisksResponse\x12,\n\x05\x64isks\x18\x01 \x03(\x0b\x32\x1d.yandex.cloud.compute.v1.Disk\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xc0\x05\n\x11\x43reateDiskRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x32\n\x04name\x18\x02 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8b\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x36.yandex.cloud.compute.v1.CreateDiskRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12\x19\n\x07type_id\x18\x05 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1d\n\x07zone_id\x18\x06 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12,\n\x04size\x18\x07 \x01(\x03\x42\x1e\xe8\xc7\x31\x01\xfa\xc7\x31\x16\x34\x31\x39\x34\x33\x30\x34-28587302322176\x12\x1c\n\x08image_id\x18\x08 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12\x1f\n\x0bsnapshot_id\x18\t \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12\x12\n\nblock_size\x18\n \x01(\x03\x12K\n\x15\x64isk_placement_policy\x18\x0b \x01(\x0b\x32,.yandex.cloud.compute.v1.DiskPlacementPolicy\x12\x1d\n\x15snapshot_schedule_ids\x18\x0c \x03(\t\x12H\n\x13hardware_generation\x18\r \x01(\x0b\x32+.yandex.cloud.compute.v1.HardwareGeneration\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x08\n\x06source\"%\n\x12\x43reateDiskMetadata\x12\x0f\n\x07\x64isk_id\x18\x01 \x01(\t\"\xea\x03\n\x11UpdateDiskRequest\x12\x1d\n\x07\x64isk_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x32\n\x04name\x18\x03 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8b\x01\n\x06labels\x18\x05 \x03(\x0b\x32\x36.yandex.cloud.compute.v1.UpdateDiskRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12\'\n\x04size\x18\x06 \x01(\x03\x42\x19\xfa\xc7\x31\x15\x34\x31\x39\x34\x33\x30\x34-4398046511104\x12K\n\x15\x64isk_placement_policy\x18\x07 \x01(\x0b\x32,.yandex.cloud.compute.v1.DiskPlacementPolicy\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"%\n\x12UpdateDiskMetadata\x12\x0f\n\x07\x64isk_id\x18\x01 \x01(\t\"2\n\x11\x44\x65leteDiskRequest\x12\x1d\n\x07\x64isk_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"%\n\x12\x44\x65leteDiskMetadata\x12\x0f\n\x07\x64isk_id\x18\x01 \x01(\t\"x\n\x19ListDiskOperationsRequest\x12\x1d\n\x07\x64isk_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"l\n\x1aListDiskOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"]\n\x0fMoveDiskRequest\x12\x1d\n\x07\x64isk_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12+\n\x15\x64\x65stination_folder_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\\\n\x10MoveDiskMetadata\x12\x0f\n\x07\x64isk_id\x18\x01 \x01(\t\x12\x18\n\x10source_folder_id\x18\x02 \x01(\t\x12\x1d\n\x15\x64\x65stination_folder_id\x18\x03 \x01(\t\"\xac\x01\n\x13RelocateDiskRequest\x12\x1d\n\x07\x64isk_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12)\n\x13\x64\x65stination_zone_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12K\n\x15\x64isk_placement_policy\x18\x03 \x01(\x0b\x32,.yandex.cloud.compute.v1.DiskPlacementPolicy\"\\\n\x14RelocateDiskMetadata\x12\x0f\n\x07\x64isk_id\x18\x01 \x01(\t\x12\x16\n\x0esource_zone_id\x18\x02 \x01(\t\x12\x1b\n\x13\x64\x65stination_zone_id\x18\x03 \x01(\t\"Z\n ListDiskSnapshotSchedulesRequest\x12\x0f\n\x07\x64isk_id\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x83\x01\n!ListDiskSnapshotSchedulesResponse\x12\x45\n\x12snapshot_schedules\x18\x01 \x03(\x0b\x32).yandex.cloud.compute.v1.SnapshotSchedule\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\x90\x10\n\x0b\x44iskService\x12r\n\x03Get\x12\'.yandex.cloud.compute.v1.GetDiskRequest\x1a\x1d.yandex.cloud.compute.v1.Disk\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/compute/v1/disks/{disk_id}\x12x\n\x04List\x12).yandex.cloud.compute.v1.ListDisksRequest\x1a*.yandex.cloud.compute.v1.ListDisksResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/compute/v1/disks\x12\x93\x01\n\x06\x43reate\x12*.yandex.cloud.compute.v1.CreateDiskRequest\x1a!.yandex.cloud.operation.Operation\":\xb2\xd2*\x1a\n\x12\x43reateDiskMetadata\x12\x04\x44isk\x82\xd3\xe4\x93\x02\x16\"\x11/compute/v1/disks:\x01*\x12\x9d\x01\n\x06Update\x12*.yandex.cloud.compute.v1.UpdateDiskRequest\x1a!.yandex.cloud.operation.Operation\"D\xb2\xd2*\x1a\n\x12UpdateDiskMetadata\x12\x04\x44isk\x82\xd3\xe4\x93\x02 2\x1b/compute/v1/disks/{disk_id}:\x01*\x12\xab\x01\n\x06\x44\x65lete\x12*.yandex.cloud.compute.v1.DeleteDiskRequest\x1a!.yandex.cloud.operation.Operation\"R\xb2\xd2*+\n\x12\x44\x65leteDiskMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x1d*\x1b/compute/v1/disks/{disk_id}\x12\xa9\x01\n\x0eListOperations\x12\x32.yandex.cloud.compute.v1.ListDiskOperationsRequest\x1a\x33.yandex.cloud.compute.v1.ListDiskOperationsResponse\".\x82\xd3\xe4\x93\x02(\x12&/compute/v1/disks/{disk_id}/operations\x12\x9c\x01\n\x04Move\x12(.yandex.cloud.compute.v1.MoveDiskRequest\x1a!.yandex.cloud.operation.Operation\"G\xb2\xd2*\x18\n\x10MoveDiskMetadata\x12\x04\x44isk\x82\xd3\xe4\x93\x02%\" /compute/v1/disks/{disk_id}:move:\x01*\x12\xac\x01\n\x08Relocate\x12,.yandex.cloud.compute.v1.RelocateDiskRequest\x1a!.yandex.cloud.operation.Operation\"O\xb2\xd2*\x1c\n\x14RelocateDiskMetadata\x12\x04\x44isk\x82\xd3\xe4\x93\x02)\"$/compute/v1/disks/{disk_id}:relocate:\x01*\x12\x8e\x01\n\x15ListSnapshotSchedules\x12\x39.yandex.cloud.compute.v1.ListDiskSnapshotSchedulesRequest\x1a:.yandex.cloud.compute.v1.ListDiskSnapshotSchedulesResponse\x12\xb1\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/compute/v1/disks/{resource_id}:listAccessBindings\x12\xf0\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x88\x01\xb2\xd2*H\n access.SetAccessBindingsMetadata\x12$access.AccessBindingsOperationResult\x82\xd3\xe4\x93\x02\x36\"1/compute/v1/disks/{resource_id}:setAccessBindings:\x01*\x12\xfc\x01\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x8e\x01\xb2\xd2*K\n#access.UpdateAccessBindingsMetadata\x12$access.AccessBindingsOperationResult\x82\xd3\xe4\x93\x02\x39\"4/compute/v1/disks/{resource_id}:updateAccessBindings:\x01*Bb\n\x1byandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;computeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.compute.v1.disk_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033yandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;compute'
  _GETDISKREQUEST.fields_by_name['disk_id']._options = None
  _GETDISKREQUEST.fields_by_name['disk_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTDISKSREQUEST.fields_by_name['folder_id']._options = None
  _LISTDISKSREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTDISKSREQUEST.fields_by_name['page_size']._options = None
  _LISTDISKSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTDISKSREQUEST.fields_by_name['page_token']._options = None
  _LISTDISKSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTDISKSREQUEST.fields_by_name['filter']._options = None
  _LISTDISKSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _LISTDISKSREQUEST.fields_by_name['order_by']._options = None
  _LISTDISKSREQUEST.fields_by_name['order_by']._serialized_options = b'\212\3101\005<=100'
  _CREATEDISKREQUEST_LABELSENTRY._options = None
  _CREATEDISKREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATEDISKREQUEST.fields_by_name['folder_id']._options = None
  _CREATEDISKREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATEDISKREQUEST.fields_by_name['name']._options = None
  _CREATEDISKREQUEST.fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _CREATEDISKREQUEST.fields_by_name['description']._options = None
  _CREATEDISKREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _CREATEDISKREQUEST.fields_by_name['labels']._options = None
  _CREATEDISKREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _CREATEDISKREQUEST.fields_by_name['type_id']._options = None
  _CREATEDISKREQUEST.fields_by_name['type_id']._serialized_options = b'\212\3101\004<=50'
  _CREATEDISKREQUEST.fields_by_name['zone_id']._options = None
  _CREATEDISKREQUEST.fields_by_name['zone_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATEDISKREQUEST.fields_by_name['size']._options = None
  _CREATEDISKREQUEST.fields_by_name['size']._serialized_options = b'\350\3071\001\372\3071\0264194304-28587302322176'
  _CREATEDISKREQUEST.fields_by_name['image_id']._options = None
  _CREATEDISKREQUEST.fields_by_name['image_id']._serialized_options = b'\212\3101\004<=50'
  _CREATEDISKREQUEST.fields_by_name['snapshot_id']._options = None
  _CREATEDISKREQUEST.fields_by_name['snapshot_id']._serialized_options = b'\212\3101\004<=50'
  _UPDATEDISKREQUEST_LABELSENTRY._options = None
  _UPDATEDISKREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATEDISKREQUEST.fields_by_name['disk_id']._options = None
  _UPDATEDISKREQUEST.fields_by_name['disk_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATEDISKREQUEST.fields_by_name['name']._options = None
  _UPDATEDISKREQUEST.fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _UPDATEDISKREQUEST.fields_by_name['description']._options = None
  _UPDATEDISKREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _UPDATEDISKREQUEST.fields_by_name['labels']._options = None
  _UPDATEDISKREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _UPDATEDISKREQUEST.fields_by_name['size']._options = None
  _UPDATEDISKREQUEST.fields_by_name['size']._serialized_options = b'\372\3071\0254194304-4398046511104'
  _DELETEDISKREQUEST.fields_by_name['disk_id']._options = None
  _DELETEDISKREQUEST.fields_by_name['disk_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTDISKOPERATIONSREQUEST.fields_by_name['disk_id']._options = None
  _LISTDISKOPERATIONSREQUEST.fields_by_name['disk_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTDISKOPERATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTDISKOPERATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTDISKOPERATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTDISKOPERATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _MOVEDISKREQUEST.fields_by_name['disk_id']._options = None
  _MOVEDISKREQUEST.fields_by_name['disk_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _MOVEDISKREQUEST.fields_by_name['destination_folder_id']._options = None
  _MOVEDISKREQUEST.fields_by_name['destination_folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _RELOCATEDISKREQUEST.fields_by_name['disk_id']._options = None
  _RELOCATEDISKREQUEST.fields_by_name['disk_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _RELOCATEDISKREQUEST.fields_by_name['destination_zone_id']._options = None
  _RELOCATEDISKREQUEST.fields_by_name['destination_zone_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _DISKSERVICE.methods_by_name['Get']._options = None
  _DISKSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002\035\022\033/compute/v1/disks/{disk_id}'
  _DISKSERVICE.methods_by_name['List']._options = None
  _DISKSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\023\022\021/compute/v1/disks'
  _DISKSERVICE.methods_by_name['Create']._options = None
  _DISKSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*\032\n\022CreateDiskMetadata\022\004Disk\202\323\344\223\002\026\"\021/compute/v1/disks:\001*'
  _DISKSERVICE.methods_by_name['Update']._options = None
  _DISKSERVICE.methods_by_name['Update']._serialized_options = b'\262\322*\032\n\022UpdateDiskMetadata\022\004Disk\202\323\344\223\002 2\033/compute/v1/disks/{disk_id}:\001*'
  _DISKSERVICE.methods_by_name['Delete']._options = None
  _DISKSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*+\n\022DeleteDiskMetadata\022\025google.protobuf.Empty\202\323\344\223\002\035*\033/compute/v1/disks/{disk_id}'
  _DISKSERVICE.methods_by_name['ListOperations']._options = None
  _DISKSERVICE.methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002(\022&/compute/v1/disks/{disk_id}/operations'
  _DISKSERVICE.methods_by_name['Move']._options = None
  _DISKSERVICE.methods_by_name['Move']._serialized_options = b'\262\322*\030\n\020MoveDiskMetadata\022\004Disk\202\323\344\223\002%\" /compute/v1/disks/{disk_id}:move:\001*'
  _DISKSERVICE.methods_by_name['Relocate']._options = None
  _DISKSERVICE.methods_by_name['Relocate']._serialized_options = b'\262\322*\034\n\024RelocateDiskMetadata\022\004Disk\202\323\344\223\002)\"$/compute/v1/disks/{disk_id}:relocate:\001*'
  _DISKSERVICE.methods_by_name['ListAccessBindings']._options = None
  _DISKSERVICE.methods_by_name['ListAccessBindings']._serialized_options = b'\202\323\344\223\0024\0222/compute/v1/disks/{resource_id}:listAccessBindings'
  _DISKSERVICE.methods_by_name['SetAccessBindings']._options = None
  _DISKSERVICE.methods_by_name['SetAccessBindings']._serialized_options = b'\262\322*H\n access.SetAccessBindingsMetadata\022$access.AccessBindingsOperationResult\202\323\344\223\0026\"1/compute/v1/disks/{resource_id}:setAccessBindings:\001*'
  _DISKSERVICE.methods_by_name['UpdateAccessBindings']._options = None
  _DISKSERVICE.methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*K\n#access.UpdateAccessBindingsMetadata\022$access.AccessBindingsOperationResult\202\323\344\223\0029\"4/compute/v1/disks/{resource_id}:updateAccessBindings:\001*'
  _globals['_GETDISKREQUEST']._serialized_start=410
  _globals['_GETDISKREQUEST']._serialized_end=457
  _globals['_LISTDISKSREQUEST']._serialized_start=460
  _globals['_LISTDISKSREQUEST']._serialized_end=630
  _globals['_LISTDISKSRESPONSE']._serialized_start=632
  _globals['_LISTDISKSRESPONSE']._serialized_end=722
  _globals['_CREATEDISKREQUEST']._serialized_start=725
  _globals['_CREATEDISKREQUEST']._serialized_end=1429
  _globals['_CREATEDISKREQUEST_LABELSENTRY']._serialized_start=1374
  _globals['_CREATEDISKREQUEST_LABELSENTRY']._serialized_end=1419
  _globals['_CREATEDISKMETADATA']._serialized_start=1431
  _globals['_CREATEDISKMETADATA']._serialized_end=1468
  _globals['_UPDATEDISKREQUEST']._serialized_start=1471
  _globals['_UPDATEDISKREQUEST']._serialized_end=1961
  _globals['_UPDATEDISKREQUEST_LABELSENTRY']._serialized_start=1374
  _globals['_UPDATEDISKREQUEST_LABELSENTRY']._serialized_end=1419
  _globals['_UPDATEDISKMETADATA']._serialized_start=1963
  _globals['_UPDATEDISKMETADATA']._serialized_end=2000
  _globals['_DELETEDISKREQUEST']._serialized_start=2002
  _globals['_DELETEDISKREQUEST']._serialized_end=2052
  _globals['_DELETEDISKMETADATA']._serialized_start=2054
  _globals['_DELETEDISKMETADATA']._serialized_end=2091
  _globals['_LISTDISKOPERATIONSREQUEST']._serialized_start=2093
  _globals['_LISTDISKOPERATIONSREQUEST']._serialized_end=2213
  _globals['_LISTDISKOPERATIONSRESPONSE']._serialized_start=2215
  _globals['_LISTDISKOPERATIONSRESPONSE']._serialized_end=2323
  _globals['_MOVEDISKREQUEST']._serialized_start=2325
  _globals['_MOVEDISKREQUEST']._serialized_end=2418
  _globals['_MOVEDISKMETADATA']._serialized_start=2420
  _globals['_MOVEDISKMETADATA']._serialized_end=2512
  _globals['_RELOCATEDISKREQUEST']._serialized_start=2515
  _globals['_RELOCATEDISKREQUEST']._serialized_end=2687
  _globals['_RELOCATEDISKMETADATA']._serialized_start=2689
  _globals['_RELOCATEDISKMETADATA']._serialized_end=2781
  _globals['_LISTDISKSNAPSHOTSCHEDULESREQUEST']._serialized_start=2783
  _globals['_LISTDISKSNAPSHOTSCHEDULESREQUEST']._serialized_end=2873
  _globals['_LISTDISKSNAPSHOTSCHEDULESRESPONSE']._serialized_start=2876
  _globals['_LISTDISKSNAPSHOTSCHEDULESRESPONSE']._serialized_end=3007
  _globals['_DISKSERVICE']._serialized_start=3010
  _globals['_DISKSERVICE']._serialized_end=5074
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import google.protobuf.wrappers_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _SortOrder:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _SortOrderEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_SortOrder.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    SORT_ORDER_UNSPECIFIED: _SortOrder.ValueType  # 0
    SORT_ORDER_ASC: _SortOrder.ValueType  # 1
    SORT_ORDER_DESC: _SortOrder.ValueType  # 2

class SortOrder(_SortOrder, metaclass=_SortOrderEnumTypeWrapper): ...

SORT_ORDER_UNSPECIFIED: SortOrder.ValueType  # 0
SORT_ORDER_ASC: SortOrder.ValueType  # 1
SORT_ORDER_DESC: SortOrder.ValueType  # 2
global___SortOrder = SortOrder

@typing.final
class Filter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    ANY_MATCH_FIELD_NUMBER: builtins.int
    INT_RANGE_FIELD_NUMBER: builtins.int
    DOUBLE_RANGE_FIELD_NUMBER: builtins.int
    DATE_RANGE_FIELD_NUMBER: builtins.int
    DURATION_RANGE_FIELD_NUMBER: builtins.int
    BOOLEAN_MATCH_FIELD_NUMBER: builtins.int
    INVERSE_FIELD_NUMBER: builtins.int
    CHANNEL_NUMBER_FIELD_NUMBER: builtins.int
    key: builtins.str
    """metadata key (user.some_key / system.created_at / analysis.speechkit.duration)"""
    inverse: builtins.bool
    @property
    def any_match(self) -> global___AnyMatchFilter:
        """find talk matched by any text filters"""

    @property
    def int_range(self) -> global___IntRangeFilter:
        """find talks with value from int range"""

    @property
    def double_range(self) -> global___DoubleRangeFilter:
        """find talks with value from double range"""

    @property
    def date_range(self) -> global___DateRangeFilter:
        """find talks with value from date range"""

    @property
    def duration_range(self) -> global___DurationRangeFilter:
        """find talks with value from duration range"""

    @property
    def boolean_match(self) -> global___BooleanFilter:
        """find talks with value equals boolean"""

    @property
    def channel_number(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """channel number to apply filter for, starting with 0. applies to all channels if not specified"""

    def __init__(
        self,
        *,
        key: builtins.str = ...,
        any_match: global___AnyMatchFilter | None = ...,
        int_range: global___IntRangeFilter | None = ...,
        double_range: global___DoubleRangeFilter | None = ...,
        date_range: global___DateRangeFilter | None = ...,
        duration_range: global___DurationRangeFilter | None = ...,
        boolean_match: global___BooleanFilter | None = ...,
        inverse: builtins.bool = ...,
        channel_number: google.protobuf.wrappers_pb2.Int64Value | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["any_match", b"any_match", "boolean_match", b"boolean_match", "channel_number", b"channel_number", "date_range", b"date_range", "double_range", b"double_range", "duration_range", b"duration_range", "filter", b"filter", "int_range", b"int_range"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["any_match", b"any_match", "boolean_match", b"boolean_match", "channel_number", b"channel_number", "date_range", b"date_range", "double_range", b"double_range", "duration_range", b"duration_range", "filter", b"filter", "int_range", b"int_range", "inverse", b"inverse", "key", b"key"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["filter", b"filter"]) -> typing.Literal["any_match", "int_range", "double_range", "date_range", "duration_range", "boolean_match"] | None: ...

global___Filter = Filter

@typing.final
class Query(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    INVERSE_FIELD_NUMBER: builtins.int
    CHANNEL_NUMBER_FIELD_NUMBER: builtins.int
    text: builtins.str
    inverse: builtins.bool
    """should or should NOT match"""
    @property
    def channel_number(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """id of channel to search ("1", "2", ..., any channel if not set)"""

    def __init__(
        self,
        *,
        text: builtins.str = ...,
        inverse: builtins.bool = ...,
        channel_number: google.protobuf.wrappers_pb2.Int64Value | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["channel_number", b"channel_number"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["channel_number", b"channel_number", "inverse", b"inverse", "text", b"text"]) -> None: ...

global___Query = Query

@typing.final
class AnyMatchFilter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUES_FIELD_NUMBER: builtins.int
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """values list to match with "OR" operator"""

    def __init__(
        self,
        *,
        values: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["values", b"values"]) -> None: ...

global___AnyMatchFilter = AnyMatchFilter

@typing.final
class BoundsInclusive(google.protobuf.message.Message):
    """indicates whether to include range boundaries"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FROM_INCLUSIVE_FIELD_NUMBER: builtins.int
    TO_INCLUSIVE_FIELD_NUMBER: builtins.int
    from_inclusive: builtins.bool
    """include from bound"""
    to_inclusive: builtins.bool
    """include to bound"""
    def __init__(
        self,
        *,
        from_inclusive: builtins.bool = ...,
        to_inclusive: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["from_inclusive", b"from_inclusive", "to_inclusive", b"to_inclusive"]) -> None: ...

global___BoundsInclusive = BoundsInclusive

@typing.final
class IntRangeFilter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FROM_VALUE_FIELD_NUMBER: builtins.int
    TO_VALUE_FIELD_NUMBER: builtins.int
    BOUNDS_INCLUSIVE_FIELD_NUMBER: builtins.int
    @property
    def from_value(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def to_value(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def bounds_inclusive(self) -> global___BoundsInclusive: ...
    def __init__(
        self,
        *,
        from_value: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        to_value: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        bounds_inclusive: global___BoundsInclusive | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["bounds_inclusive", b"bounds_inclusive", "from_value", b"from_value", "to_value", b"to_value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["bounds_inclusive", b"bounds_inclusive", "from_value", b"from_value", "to_value", b"to_value"]) -> None: ...

global___IntRangeFilter = IntRangeFilter

@typing.final
class DoubleRangeFilter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FROM_VALUE_FIELD_NUMBER: builtins.int
    TO_VALUE_FIELD_NUMBER: builtins.int
    BOUNDS_INCLUSIVE_FIELD_NUMBER: builtins.int
    @property
    def from_value(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def to_value(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def bounds_inclusive(self) -> global___BoundsInclusive: ...
    def __init__(
        self,
        *,
        from_value: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
        to_value: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
        bounds_inclusive: global___BoundsInclusive | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["bounds_inclusive", b"bounds_inclusive", "from_value", b"from_value", "to_value", b"to_value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["bounds_inclusive", b"bounds_inclusive", "from_value", b"from_value", "to_value", b"to_value"]) -> None: ...

global___DoubleRangeFilter = DoubleRangeFilter

@typing.final
class DateRangeFilter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FROM_VALUE_FIELD_NUMBER: builtins.int
    TO_VALUE_FIELD_NUMBER: builtins.int
    BOUNDS_INCLUSIVE_FIELD_NUMBER: builtins.int
    @property
    def from_value(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def to_value(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def bounds_inclusive(self) -> global___BoundsInclusive: ...
    def __init__(
        self,
        *,
        from_value: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        to_value: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        bounds_inclusive: global___BoundsInclusive | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["bounds_inclusive", b"bounds_inclusive", "from_value", b"from_value", "to_value", b"to_value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["bounds_inclusive", b"bounds_inclusive", "from_value", b"from_value", "to_value", b"to_value"]) -> None: ...

global___DateRangeFilter = DateRangeFilter

@typing.final
class DurationRangeFilter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FROM_VALUE_FIELD_NUMBER: builtins.int
    TO_VALUE_FIELD_NUMBER: builtins.int
    BOUNDS_INCLUSIVE_FIELD_NUMBER: builtins.int
    @property
    def from_value(self) -> google.protobuf.duration_pb2.Duration: ...
    @property
    def to_value(self) -> google.protobuf.duration_pb2.Duration: ...
    @property
    def bounds_inclusive(self) -> global___BoundsInclusive: ...
    def __init__(
        self,
        *,
        from_value: google.protobuf.duration_pb2.Duration | None = ...,
        to_value: google.protobuf.duration_pb2.Duration | None = ...,
        bounds_inclusive: global___BoundsInclusive | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["bounds_inclusive", b"bounds_inclusive", "from_value", b"from_value", "to_value", b"to_value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["bounds_inclusive", b"bounds_inclusive", "from_value", b"from_value", "to_value", b"to_value"]) -> None: ...

global___DurationRangeFilter = DurationRangeFilter

@typing.final
class BooleanFilter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    value: builtins.bool
    def __init__(
        self,
        *,
        value: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["value", b"value"]) -> None: ...

global___BooleanFilter = BooleanFilter

@typing.final
class SortData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIELDS_FIELD_NUMBER: builtins.int
    @property
    def fields(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SortField]: ...
    def __init__(
        self,
        *,
        fields: collections.abc.Iterable[global___SortField] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["fields", b"fields"]) -> None: ...

global___SortData = SortData

@typing.final
class SortField(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIELD_FIELD_NUMBER: builtins.int
    ORDER_FIELD_NUMBER: builtins.int
    POSITION_FIELD_NUMBER: builtins.int
    field: builtins.str
    """sorting key"""
    order: global___SortOrder.ValueType
    """sorting order by current `field`"""
    position: builtins.int
    """number of field in comparing order (sort by key1 (position = 0), then key2 (position = 1), then key3...)"""
    def __init__(
        self,
        *,
        field: builtins.str = ...,
        order: global___SortOrder.ValueType = ...,
        position: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["field", b"field", "order", b"order", "position", b"position"]) -> None: ...

global___SortField = SortField



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing
import yandex.cloud.organizationmanager.v1.user_ssh_key_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetUserSshKeyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_SSH_KEY_ID_FIELD_NUMBER: builtins.int
    user_ssh_key_id: builtins.str
    def __init__(
        self,
        *,
        user_ssh_key_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["user_ssh_key_id", b"user_ssh_key_id"]) -> None: ...

global___GetUserSshKeyRequest = GetUserSshKeyRequest

@typing.final
class ListUserSshKeysRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    SUBJECT_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    organization_id: builtins.str
    subject_id: builtins.str
    """if empty, list all organization keys"""
    page_size: builtins.int
    page_token: builtins.str
    def __init__(
        self,
        *,
        organization_id: builtins.str = ...,
        subject_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["organization_id", b"organization_id", "page_size", b"page_size", "page_token", b"page_token", "subject_id", b"subject_id"]) -> None: ...

global___ListUserSshKeysRequest = ListUserSshKeysRequest

@typing.final
class ListUserSshKeysResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SSH_KEYS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    @property
    def ssh_keys(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.organizationmanager.v1.user_ssh_key_pb2.UserSshKey]: ...
    def __init__(
        self,
        *,
        ssh_keys: collections.abc.Iterable[yandex.cloud.organizationmanager.v1.user_ssh_key_pb2.UserSshKey] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "ssh_keys", b"ssh_keys"]) -> None: ...

global___ListUserSshKeysResponse = ListUserSshKeysResponse

@typing.final
class CreateUserSshKeyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    SUBJECT_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    EXPIRES_AT_FIELD_NUMBER: builtins.int
    organization_id: builtins.str
    subject_id: builtins.str
    name: builtins.str
    data: builtins.str
    @property
    def expires_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        organization_id: builtins.str = ...,
        subject_id: builtins.str = ...,
        name: builtins.str = ...,
        data: builtins.str = ...,
        expires_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["expires_at", b"expires_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "expires_at", b"expires_at", "name", b"name", "organization_id", b"organization_id", "subject_id", b"subject_id"]) -> None: ...

global___CreateUserSshKeyRequest = CreateUserSshKeyRequest

@typing.final
class CreateUserSshKeyMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_SSH_KEY_ID_FIELD_NUMBER: builtins.int
    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    user_ssh_key_id: builtins.str
    organization_id: builtins.str
    def __init__(
        self,
        *,
        user_ssh_key_id: builtins.str = ...,
        organization_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["organization_id", b"organization_id", "user_ssh_key_id", b"user_ssh_key_id"]) -> None: ...

global___CreateUserSshKeyMetadata = CreateUserSshKeyMetadata

@typing.final
class UpdateUserSshKeyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_SSH_KEY_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    EXPIRES_AT_FIELD_NUMBER: builtins.int
    user_ssh_key_id: builtins.str
    name: builtins.str
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask: ...
    @property
    def expires_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        user_ssh_key_id: builtins.str = ...,
        name: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        expires_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["expires_at", b"expires_at", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["expires_at", b"expires_at", "name", b"name", "update_mask", b"update_mask", "user_ssh_key_id", b"user_ssh_key_id"]) -> None: ...

global___UpdateUserSshKeyRequest = UpdateUserSshKeyRequest

@typing.final
class UpdateUserSshKeyMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_SSH_KEY_ID_FIELD_NUMBER: builtins.int
    user_ssh_key_id: builtins.str
    def __init__(
        self,
        *,
        user_ssh_key_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["user_ssh_key_id", b"user_ssh_key_id"]) -> None: ...

global___UpdateUserSshKeyMetadata = UpdateUserSshKeyMetadata

@typing.final
class DeleteUserSshKeyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_SSH_KEY_ID_FIELD_NUMBER: builtins.int
    user_ssh_key_id: builtins.str
    def __init__(
        self,
        *,
        user_ssh_key_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["user_ssh_key_id", b"user_ssh_key_id"]) -> None: ...

global___DeleteUserSshKeyRequest = DeleteUserSshKeyRequest

@typing.final
class DeleteUserSshKeyMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_SSH_KEY_ID_FIELD_NUMBER: builtins.int
    user_ssh_key_id: builtins.str
    def __init__(
        self,
        *,
        user_ssh_key_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["user_ssh_key_id", b"user_ssh_key_id"]) -> None: ...

global___DeleteUserSshKeyMetadata = DeleteUserSshKeyMetadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _SubjectType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _SubjectTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_SubjectType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    SUBJECT_TYPE_UNSPECIFIED: _SubjectType.ValueType  # 0
    USER_ACCOUNT: _SubjectType.ValueType  # 1
    SERVICE_ACCOUNT: _SubjectType.ValueType  # 2
    GROUP: _SubjectType.ValueType  # 3
    INVITEE: _SubjectType.ValueType  # 4

class SubjectType(_SubjectType, metaclass=_SubjectTypeEnumTypeWrapper): ...

SUBJECT_TYPE_UNSPECIFIED: SubjectType.ValueType  # 0
USER_ACCOUNT: SubjectType.ValueType  # 1
SERVICE_ACCOUNT: SubjectType.ValueType  # 2
GROUP: SubjectType.ValueType  # 3
INVITEE: SubjectType.ValueType  # 4
global___SubjectType = SubjectType

@typing.final
class SubjectClaims(google.protobuf.message.Message):
    """Claims representation, see https://openid.net/specs/openid-connect-core-1_0.html#StandardClaims for details."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUB_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    GIVEN_NAME_FIELD_NUMBER: builtins.int
    FAMILY_NAME_FIELD_NUMBER: builtins.int
    PREFERRED_USERNAME_FIELD_NUMBER: builtins.int
    PICTURE_FIELD_NUMBER: builtins.int
    EMAIL_FIELD_NUMBER: builtins.int
    ZONEINFO_FIELD_NUMBER: builtins.int
    LOCALE_FIELD_NUMBER: builtins.int
    PHONE_NUMBER_FIELD_NUMBER: builtins.int
    SUB_TYPE_FIELD_NUMBER: builtins.int
    FEDERATION_FIELD_NUMBER: builtins.int
    LAST_AUTHENTICATED_AT_FIELD_NUMBER: builtins.int
    sub: builtins.str
    """Subject - Identifier for the End-User at the Issuer."""
    name: builtins.str
    """End-User's full name in displayable form including all name parts, possibly including titles and suffixes, ordered according to the End-User's locale and preferences."""
    given_name: builtins.str
    """Given name(s) or first name(s) of the End-User. Note that in some cultures, people can have multiple given names; all can be present, with the names being separated by space characters."""
    family_name: builtins.str
    """Surname(s) or last name(s) of the End-User. Note that in some cultures, people can have multiple family names or no family name; all can be present, with the names being separated by space characters."""
    preferred_username: builtins.str
    """Shorthand name by which the End-User wishes to be referred to at the RP, such as janedoe or j.doe.
    This value MAY be any valid JSON string including special characters such as @, /, or whitespace. The RP MUST NOT rely upon this value being unique, as discussed in Section 5.7.
    """
    picture: builtins.str
    """URL of the End-User's profile picture. This URL MUST refer to an image file (for example, a PNG, JPEG, or GIF image file),
    rather than to a Web page containing an image. Note that this URL SHOULD specifically reference a profile photo of the End-User suitable for displaying when describing the End-User, rather than an arbitrary photo taken by the End-User.
    """
    email: builtins.str
    """End-User's preferred e-mail address. Its value MUST conform to the RFC 5322 [RFC5322] addr-spec syntax.
    The RP MUST NOT rely upon this value being unique, as discussed in Section 5.7.
    """
    zoneinfo: builtins.str
    """String from zoneinfo [zoneinfo] time zone database representing the End-User's time zone. For example, Europe/Paris or America/Los_Angeles."""
    locale: builtins.str
    """End-User's locale, represented as a BCP47 [RFC5646] language tag. This is typically an ISO 639-1 Alpha-2 [ISO639-1] language code in lowercase and an ISO 3166-1 Alpha-2 [ISO3166-1] country code in uppercase, separated by a dash.
    For example, en-US or fr-CA. As a compatibility note, some implementations have used an underscore as the separator rather than a dash, for example, en_US; Relying Parties MAY choose to accept this locale syntax as well.
    """
    phone_number: builtins.str
    """End-User's preferred telephone number. E.164 [E.164] is RECOMMENDED as the format of this Claim, for example, +1 (425) 555-1212 or +56 (2) 687 2400.
    If the phone number contains an extension, it is RECOMMENDED that the extension be represented using the RFC 3966 [RFC3966] extension syntax, for example, +1 (604) 555-1234;ext=5678.
    """
    sub_type: global___SubjectType.ValueType
    """Subject type."""
    @property
    def federation(self) -> global___Federation:
        """User federation, non-empty only for federated users."""

    @property
    def last_authenticated_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Last time the access token was created. Filled only for federated users (not for global users)."""

    def __init__(
        self,
        *,
        sub: builtins.str = ...,
        name: builtins.str = ...,
        given_name: builtins.str = ...,
        family_name: builtins.str = ...,
        preferred_username: builtins.str = ...,
        picture: builtins.str = ...,
        email: builtins.str = ...,
        zoneinfo: builtins.str = ...,
        locale: builtins.str = ...,
        phone_number: builtins.str = ...,
        sub_type: global___SubjectType.ValueType = ...,
        federation: global___Federation | None = ...,
        last_authenticated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["federation", b"federation", "last_authenticated_at", b"last_authenticated_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["email", b"email", "family_name", b"family_name", "federation", b"federation", "given_name", b"given_name", "last_authenticated_at", b"last_authenticated_at", "locale", b"locale", "name", b"name", "phone_number", b"phone_number", "picture", b"picture", "preferred_username", b"preferred_username", "sub", b"sub", "sub_type", b"sub_type", "zoneinfo", b"zoneinfo"]) -> None: ...

global___SubjectClaims = SubjectClaims

@typing.final
class Federation(google.protobuf.message.Message):
    """Minimalistic analog of yandex.cloud.organizationmanager.v1.saml.Federation"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the federation."""
    name: builtins.str
    """Name of the federation. The name is unique within the cloud or organization"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id", "name", b"name"]) -> None: ...

global___Federation = Federation
